package com.ruoyi.system.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.system.domain.TdFileProvide;

/**
 * 文件下发Mapper接口
 * 
 * @author ruoyi
 * @date 2024-04-23
 */
public interface TdFileProvideMapper extends BaseMapper<TdFileProvide>
{
    /**
     * 查询文件下发
     *
     * @param fileId 文件下发主键
     * @return 文件下发
     */
    public TdFileProvide selectTdFileProvideByFileId(String fileId);

    /**
     * 查询文件下发列表
     *
     * @param tdFileProvide 文件下发
     * @return 文件下发集合
     */
    public List<TdFileProvide> selectTdFileProvideList(TdFileProvide tdFileProvide);

    /**
     * 新增文件下发
     *
     * @param tdFileProvide 文件下发
     * @return 结果
     */
    public int insertTdFileProvide(TdFileProvide tdFileProvide);

    /**
     * 修改文件下发
     *
     * @param tdFileProvide 文件下发
     * @return 结果
     */
    public int updateTdFileProvide(TdFileProvide tdFileProvide);

    /**
     * 删除文件下发
     *
     * @param fileId 文件下发主键
     * @return 结果
     */
    public int deleteTdFileProvideByFileId(Long fileId);

    /**
     * 批量删除文件下发
     *
     * @param fileIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTdFileProvideByFileIds(String[] fileIds);
}
